@@ -17,10 +17,20 @@ extract.reference.allele <- function(stat){
   names(RefAllele) <- snps
   names(EffectAllele) <- snps
   
+  # use the same strategy as in recover.stat() to determine which allele is used as the reference allele when merging data or creating scores from multiple studies
   for(i in 1:nstudy){
     s <- stat[[i]][, 'SNP']
-    RefAllele[s] <- stat[[i]][, 'RefAllele']
-    EffectAllele[s] <- stat[[i]][, 'EffectAllele']
+    
+    if(any(is.na(RefAllele[s]))){
+      s <- s[is.na(RefAllele[s])]
+      RefAllele[s] <- stat[[i]][s, 'RefAllele']
+    }
+    
+    s <- stat[[i]][, 'SNP']
+    if(any(is.na(EffectAllele[s]))){
+      s <- s[is.na(EffectAllele[s])]
+      EffectAllele[s] <- stat[[i]][s, 'EffectAllele']
+    }
   }
   
   list(RefAllele = RefAllele, EffectAllele = EffectAllele)
